@extends('layouts.nav')

@section('title', 'Age Analysis Report')

@section('content')

<div class="d-sm-flex align-items-center justify-content-between mb-4">
    <h1 class="h3 mb-0 text-gray-800">Age Analysis Report</h1>
</div>

<div class="card shadow mb-4">
    <!-- Display Errors (if any) -->
    @if ($errors->any())
        <div class="alert alert-danger">
            <ul>
                @foreach ($errors->all() as $error)
                    <li>{{ $error }}</li>
                @endforeach
            </ul>
        </div>
    @endif

    <!-- Report Filters -->
    <div class="card-header py-3">
        <h6 class="m-0 font-weight-bold text-primary">Report Filters</h6>
    </div>
    <div class="card-body">
        <form action="{{ route('AgeAnalysisReport.data') }}" method="post">
            @csrf

            <div class="form-group row">
                <div class="col-md-4 mb-3">
                    <label class="font-weight-bold text-secondary">Report Type</label>
                    <select class="form-control" name="report_type" id="reportType" required>
                        <option value="" disabled {{ request()->filled('report_type') ? '' : 'selected' }}>Select</option>
                        <option value="summary" {{ request()->input('report_type') == 'summary' ? 'selected' : '' }}>Summary</option>
                        <option value="detailed" {{ request()->input('report_type') == 'detailed' ? 'selected' : '' }}>Detailed</option>
                    </select>
                </div>

                <div class="col-md-4 mb-3">
                    <label class="font-weight-bold text-secondary">Date From</label>
                    <input type="date" class="form-control" name="from_date"
                           value="{{ request()->input('from_date', now()->format('Y-m-d')) }}" required>
                </div>

                <div class="col-md-4 mb-3">
                    <label class="font-weight-bold text-secondary">Date To</label>
                    <input type="date" class="form-control" name="to_date"
                           value="{{ request()->input('to_date', now()->format('Y-m-d')) }}" required>
                </div>
            </div>

            <div style="display: flex;">
                <button type="submit" id="viewButton" class="btn btn-primary btn-user btn-block" style="width: 100px; height: 40px; margin-right: 10px; margin-top: 6px;">View</button>
                <a href="{{ route('AgeAnalysisReport') }}" class="btn btn-secondary btn-user btn-block" style="width: 100px;">Refresh</a>
            </div>
        </form>
    </div>

    <!-- Only show report tables if a report type is set in the request -->
    @if(request()->filled('report_type'))
        <div class="card-body">

            {{-- Summary Report --}}
            @if(request()->input('report_type') == 'summary')
                <div id="summaryTable">
                    <table class="table table-bordered">
                        <thead>
                            <tr >
                                <th>Tenant</th>
                                <th>180 Days</th>
                                <th>150 Days</th>
                                <th>120 Days</th>
                                <th>90 Days</th>
                                <th>60 Days</th>
                                <th>30 Days</th>
                                <th>Current</th>
                                <th>Balance</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td>Sir Henry</td>
                                <td>500</td>  <!-- 180 Days -->
                                <td></td>     <!-- 150 Days (empty) -->
                                <td></td>      <!-- 120 Days (empty) -->
                                <td></td>      <!-- 90 Days (empty) -->
                                <td>100</td>   <!-- 60 Days -->
                                <td></td>      <!-- 30 Days (empty) -->
                                <td></td>      <!-- Current (empty) -->
                                <td>600</td>   <!-- Balance (sum of 500 + 100) -->
                            </tr>
                            <tr>
                                <td>Sir Murin</td>
                                <td></td>      <!-- 180 Days (empty) -->
                                <td></td>      <!-- 150 Days (empty) -->
                                <td></td>      <!-- 120 Days (empty) -->
                                <td>150</td>   <!-- 90 Days -->
                                <td></td>      <!-- 60 Days (empty) -->
                                <td></td>      <!-- 30 Days (empty) -->
                                <td>10</td>    <!-- Current -->
                                <td>160</td>   <!-- Balance (sum of 150 + 10) -->
                            </tr>
                        </tbody>
                        <tfoot>
                        <tr>
                                <th>Totals:</th>
                                <th>180 Days<br><span style="color: blue;">500</span></th>
                                <th>150 Days<br><span style="color: blue;">0</span></th>
                                <th>120 Days<br><span style="color: blue;">0</span></th>
                                <th>90 Days<br><span style="color: blue;">150</span></th>
                                <th>60 Days<br><span style="color: blue;">100</span></th>
                                <th>30 Days<br><span style="color: blue;">0</span></th>
                                <th>Current<br><span style="color: blue;">10</span></th>
                                <th>Balance<br><span style="color: blue;">750</span></th>
                            </tr>
                            <tr>
                                <th>% of Balance:</th>
                                <td>66%</td>    <!-- 500/760 = 65.79% -->
                                <td>0%</td>      <!-- 0/760 -->
                                <td>0%</td>      <!-- 0/760 -->
                                <td>20%</td>     <!-- 150/760 = 19.74% -->
                                <td>13%</td>     <!-- 100/760 = 13.16% -->
                                <td>0%</td>      <!-- 0/760 -->
                                <td>1%</td>      <!-- 10/760 = 1.32% -->
                                <td></td>        <!-- Empty as requested -->
                            </tr>
                        </tfoot>
                    </table>
                </div>
            @endif
        </div>
    @endif
</div>
@endsection
